TBNU 
==
Terminal Based Notes Utility!
-----

TBNU is a super easy to use notes program. Takes no time to set up and has simple use.

## Features
- Write down whatever very quickly
- Thats literally it

## How to Use
    